@@ -11,6 +11,7 @@ import logging
 import asyncio
 import atexit
 import textwrap
+import traceback
 from shlex import quote as shellquote
 from argparse import ArgumentParser, Action, SUPPRESS, RawDescriptionHelpFormatter
 from contextlib import ExitStack
@@ -47,6 +48,7 @@ from ._util import (
     ANSI,
     currently_in_container,
     LoggingFileHandler,
+    write_atomic,
 )
 from ._util import StructuredLogMessage as _
 
@@ -72,7 +74,7 @@ def main(args=None):
             check(**vars(args))
         elif args.command == "run":
             runner(**vars(args))
-        elif args.command == "run_self_test":
+        elif args.command in ("run_self_test", "run-self-test"):
             run_self_test(**vars(args))
         elif args.command == "localize":
             localize(**vars(args))
@@ -825,7 +827,12 @@ def runner(
                     logger.notice(
                         "run with --verbose to include task standard error streams in this log"
                     )
-            info = runtime.error_json(exn)
+            info = runtime.error_json(
+                exn,
+                traceback=(
+                    traceback.format_exc() if not isinstance(exn, Error.RuntimeError) else None
+                ),
+            )
             if rundir:
                 info["dir"] = rundir
             if from_rundir and from_rundir != rundir:
@@ -1307,17 +1314,18 @@ def runner_standard_output(content, stdout_file, error_json, log_json):
     Write the runner output/error JSON in the way requested by the user
     """
     if error_json or stdout_file or "error" not in content:
-        content_json = json.dumps(content, indent=(None if log_json else 2))
+        content_json = json.dumps(content, indent=(None if log_json else 2), sort_keys=True)
         if stdout_file:
-            with open(stdout_file, "w") as outfile:
-                print(content_json, file=outfile)
+            write_atomic(content_json, stdout_file)
         else:
             print(content_json)
 
 
 def fill_run_self_test_subparser(subparsers):
     run_parser = subparsers.add_parser(
-        "run_self_test", help="Run a short built-in workflow to test system configuration"
+        "run_self_test",
+        aliases=["run-self-test"],
+        help="Run a short built-in workflow to test system configuration",
     )
     run_parser.add_argument(
         "--dir",
