@@ -71,9 +71,8 @@ class Base:
 
         @static([Type.String(), Type.String(), Type.String()], Type.String())
         def sub(input: Value.String, pattern: Value.String, replace: Value.String) -> Value.String:
-            return Value.String(
-                regex.compile(pattern.value, flags=regex.POSIX).sub(replace.value, input.value)
-            )
+            pattern_re = regex.compile(pattern.value, flags=regex.POSIX)  # pylint: disable=E1101
+            return Value.String(pattern_re.sub(replace.value, input.value))
 
         static([Type.String(), Type.String(optional=True)], Type.String())(basename)
 
@@ -785,7 +784,8 @@ class _SelectAll(EagerFunction):
         arrty = arr.type
         assert isinstance(arrty, Type.Array)
         return Value.Array(
-            arrty.item_type, [arg for arg in arr.value if not isinstance(arg, Value.Null)]
+            arrty.item_type.copy(optional=False),
+            [arg for arg in arr.value if not isinstance(arg, Value.Null)],
         )
 
 
