@@ -197,7 +197,7 @@ class SwarmContainer(TaskContainer):
                 "command": [
                     "/bin/bash",
                     "-c",
-                    "id; ls -Rl ..; bash ../command >> ../stdout.txt 2>> ../stderr.txt",
+                    "id; ls -Rl ..; bash -l ../command >> ../stdout.txt 2>> ../stderr.txt",
                 ],
                 # restart_policy 'none' so that swarm runs the container just once
                 "restart_policy": docker.types.RestartPolicy("none"),
@@ -210,6 +210,18 @@ class SwarmContainer(TaskContainer):
                 "container_labels": {"miniwdl_run_id": self.run_id},
                 "env": [f"{k}={v}" for (k, v) in self.runtime_values.get("env", {}).items()],
             }
+            network = self.runtime_values.get("docker_network", None)
+            if network:
+                if network in self.cfg.get_list("docker_swarm", "allow_networks"):
+                    kwargs["networks"] = [network]
+                else:
+                    logger.warning(
+                        _(
+                            "runtime.docker_network ignored; network name must appear in JSON list from config"
+                            " [docker_swarm] allow_networks / env MINIWDL__DOCKER_SWARM__ALLOW_NETWORKS",
+                            docker_network=network,
+                        )
+                    )
             if self.runtime_values.get("privileged", False) is True:
                 logger.warning("runtime.privileged enabled (security & portability warning)")
                 kwargs["cap_add"] = ["ALL"]
