@@ -125,7 +125,7 @@ def run_local_task(
                     )
                 # create out/ and outputs.json
                 _outputs = link_outputs(
-                    cached, run_dir, hardlinks=cfg["file_io"].get_bool("output_hardlinks")
+                    cache, cached, run_dir, hardlinks=cfg["file_io"].get_bool("output_hardlinks")
                 )
                 write_values_json(
                     cached, os.path.join(run_dir, "outputs.json"), namespace=task.name
@@ -172,14 +172,18 @@ def run_local_task(
                 # evaluate runtime fields
                 stdlib = InputStdLib(task.effective_wdl_version, logger, container)
                 container.runtime_values = _eval_task_runtime(
-                    cfg, logger, task, posix_inputs, container, container_env, stdlib
+                    cfg, logger, run_id, task, posix_inputs, container, container_env, stdlib
                 )
 
                 # interpolate command
+                # pylint: disable=E1101
+                placeholder_re = regex.compile(
+                    cfg["task_runtime"]["placeholder_regex"], flags=regex.POSIX
+                )
                 setattr(
                     stdlib,
                     "_placeholder_regex",
-                    regex.compile(cfg["task_runtime"]["placeholder_regex"], flags=regex.POSIX),
+                    placeholder_re,
                 )  # hack to pass regex to WDL.Expr.Placeholder._eval
                 command = _util.strip_leading_whitespace(
                     task.command.eval(container_env, stdlib).value
@@ -199,7 +203,7 @@ def run_local_task(
 
                 # create output_links
                 outputs = link_outputs(
-                    outputs, run_dir, hardlinks=cfg["file_io"].get_bool("output_hardlinks")
+                    cache, outputs, run_dir, hardlinks=cfg["file_io"].get_bool("output_hardlinks")
                 )
 
                 # process outputs through plugins
@@ -446,22 +450,19 @@ def _fspaths(env: Env.Bindings[Value.Base]) -> Set[str]:
 def _eval_task_runtime(
     cfg: config.Loader,
     logger: logging.Logger,
+    run_id: str,
     task: Tree.Task,
     inputs: Env.Bindings[Value.Base],
     container: "runtime.task_container.TaskContainer",
     env: Env.Bindings[Value.Base],
     stdlib: StdLib.Base,
 ) -> Dict[str, Union[int, str, List[int], List[str]]]:
+    runtime_defaults = cfg.get_dict("task_runtime", "defaults")
+    if run_id.startswith("download-"):
+        runtime_defaults.update(cfg.get_dict("task_runtime", "download_defaults"))
     runtime_values = {}
-    for key, v in cfg["task_runtime"].get_dict("defaults").items():
-        if isinstance(v, str):
-            runtime_values[key] = Value.String(v)
-        elif isinstance(v, int):
-            runtime_values[key] = Value.Int(v)
-        elif isinstance(v, bool):
-            runtime_values[key] = Value.Boolean(v)
-        else:
-            raise Error.InputError(f"invalid default runtime setting {key} = {v}")
+    for key, v in runtime_defaults.items():
+        runtime_values[key] = Value.from_json(Type.Any(), v)
     for key, expr in task.runtime.items():  # evaluate expressions in source code
         runtime_values[key] = expr.eval(env, stdlib)
     for b in inputs.enter_namespace("runtime"):
@@ -484,6 +485,9 @@ def _eval_task_runtime(
             # TODO: ask TaskContainer to choose preferred candidate
             docker_value = docker_value.value[0]
         ans["docker"] = docker_value.coerce(Type.String()).value
+    if "docker_network" in runtime_values:
+        network_value = runtime_values["docker_network"]
+        ans["docker_network"] = network_value.coerce(Type.String()).value
 
     if (
         isinstance(runtime_values.get("privileged", None), Value.Boolean)
@@ -789,7 +793,7 @@ def _check_directory(host_path: str, output_name: str) -> None:
 
 
 def link_outputs(
-    outputs: Env.Bindings[Value.Base], run_dir: str, hardlinks: bool = False
+    cache: CallCache, outputs: Env.Bindings[Value.Base], run_dir: str, hardlinks: bool = False
 ) -> Env.Bindings[Value.Base]:
     """
     Following a successful run, the output files may be scattered throughout a complex directory
@@ -800,12 +804,17 @@ def link_outputs(
 
     def map_paths(v: Value.Base, dn: str) -> Value.Base:
         if isinstance(v, (Value.File, Value.Directory)):
-            if os.path.exists(v.value):
+            target = (
+                v.value
+                if os.path.exists(v.value)
+                else cache.get_download(v.value, isinstance(v, Value.Directory))
+            )
+            if target:
                 target = os.path.realpath(v.value)
                 if not hardlinks and path_really_within(target, os.path.dirname(run_dir)):
                     # make symlink relative
                     target = os.path.relpath(target, start=os.path.realpath(dn))
-                link = os.path.join(dn, os.path.basename(v.value))
+                link = os.path.join(dn, os.path.basename(v.value.rstrip("/")))
                 os.makedirs(dn, exist_ok=False)
                 if hardlinks:
                     # TODO: what if target is an input from a different filesystem?
