@@ -704,7 +704,7 @@ def run_local_workflow(
                     )
                 )
             _outputs = link_outputs(
-                cached, run_dir, hardlinks=cfg["file_io"].get_bool("output_hardlinks")
+                cache, cached, run_dir, hardlinks=cfg["file_io"].get_bool("output_hardlinks")
             )
             write_values_json(
                 cached, os.path.join(run_dir, "outputs.json"), namespace=workflow.name
@@ -864,7 +864,7 @@ def _workflow_main_loop(
 
             # create output_links
             outputs = link_outputs(
-                state.outputs, run_dir, hardlinks=cfg["file_io"].get_bool("output_hardlinks")
+                cache, state.outputs, run_dir, hardlinks=cfg["file_io"].get_bool("output_hardlinks")
             )
 
             # process outputs through plugins
